@@ -169,6 +169,8 @@ class Table:
     is_view: Optional[bool] = attr.ib(default=None, converter=default_if_none)
     programmatic_descriptions: List[ProgrammaticDescription] = []
     integration_key: Optional[str] = None
+    total_usage: Optional[int] = None
+    unique_usage: Optional[int] = None
 
 
 class TableSchema(AttrsSchema):
@@ -186,6 +188,8 @@ class TableSummary:
     description: Optional[str] = attr.ib(default=None)
     schema_description: Optional[str] = attr.ib(default=None)
     last_updated_timestamp: Optional[int] = attr.ib(default=None)
+    total_usage: Optional[int] = attr.ib(default=None)
+    unique_usage: Optional[int] = attr.ib(default=None)
 
 
 class TableSummarySchema(AttrsSchema):
